@@ -1,9 +1,10 @@
 package Dist::Zilla::PluginBundle::AVAR;
-our $AUTHORITY = 'cpan:AVAR';
-$Dist::Zilla::PluginBundle::AVAR::VERSION = '0.32';
+BEGIN {
+  $Dist::Zilla::PluginBundle::AVAR::AUTHORITY = 'cpan:AVAR';
+}
+BEGIN { $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.33'; }
 use 5.10.0;
 use Moose;
-use experimental 'smartmatch';
 use Moose::Autobox;
 
 with 'Dist::Zilla::Role::PluginBundle';
@@ -59,29 +60,28 @@ sub bundle_config {
     my $page;
     my ($repo_url, $repo_web);
 
-    given ($bugtracker) {
-        when ('github') { $tracker = "http://github.com/$github_user/$ldist/issues" }
-        when ('rt')     {
-            $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
-            $tracker_mailto = sprintf 'bug-%s@rt.cpan.org', $dist;
-        }
-        default         { $tracker = $bugtracker }
+    if ($bugtracker eq 'github') {
+        $tracker = "http://github.com/$github_user/$ldist/issues";
+    } elsif ($bugtracker eq 'rt') {
+        $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
+        $tracker_mailto = sprintf 'bug-%s@rt.cpan.org', $dist;
+    } else {
+        $tracker = $bugtracker;
     }
 
-    given ($repository_url) {
-        when (not defined) {
-            $repo_web = "http://github.com/$github_user/$ldist";
-            $repo_url = "git://github.com/$github_user/$ldist.git";
-        }
-        default {
-            $repo_web = $repository_web;
-            $repo_url = $repository_url;
-        }
+
+    unless ($repository_url) {
+        $repo_web = "http://github.com/$github_user/$ldist";
+        $repo_url = "git://github.com/$github_user/$ldist.git";
+    } else {
+        $repo_web = $repository_web;
+        $repo_url = $repository_url;
     }
 
-    given ($homepage) {
-        when (not defined) { $page = "http://metacpan.org/release/$dist" }
-        default            { $page = $homepage }
+    unless (defined $homepage) {
+        $page = "http://metacpan.org/release/$dist";
+    } else {
+        $page = $homepage;
     }
 
     my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config({
@@ -95,6 +95,8 @@ sub bundle_config {
                 'PodCoverageTests',
                 # Use my MakeMaker
                 'MakeMaker',
+                # Use the use_begin argument to PkgVersion
+                'PkgVersion',
             ],
         },
     });
@@ -102,6 +104,11 @@ sub bundle_config {
     my $prefix = 'Dist::Zilla::Plugin::';
     my @extra = map {[ "$section->{name}/$_->[0]" => "$prefix$_->[0]" => $_->[1] ]}
     (
+        [
+            'PkgVersion' => {
+                use_begin => 1,
+            },
+        ],
         [
             'Git::NextVersion' => {
                 first_version => '0.01',
